Learn R Programming

gtcorr (version 0.2-1)

gtcorr.hierarchical: Calculate the efficiency of hierarchical group testing procedures for nested and random arrangements

Description

‘gtcorr.hierarchical’ calculates the efficiencies of hierarchical group testing procedures for nested and random arrangements, allowing for correlation between units and test error.

Usage

gtcorr.hierarchical(n, m = 1, p, sigma = 0, se = 1, sp = 1, arrangement = c("nested", "random"), model = c("beta-binomial", "Madsen", "Morel-Neerchal"), ...)

Arguments

n
a numeric vector of pool sizes where n[s] is the size of a pool in stage s. The size of a pool in the last stage is 1, which can be omitted.
m
cluster size.
p
probability of a unit testing positive.
sigma
pairwise correlation of two units in a cluster.
se
sensitivity. The probability that a pool of units tests positive given than at least one unit in that pool is positive
sp
specificity. The probability that a pool of units tests negative given that at least one unit in that pool is negative
arrangement
how clusters are arranged. Should be ‘nested’ or ‘random’.
model
probability model for clusters. Should be ‘beta-binomial’, ‘Madsen’, or ‘Morel-Neerchal’.
...
runs
for a random arrangement, number of Monte Carlo simulations to perform to calculate the probability of a pool having no positive units. Default is 1000.

Value

n
number of units per pool at each stage.
param.grid
a data frame containing the values of p, sigma, se, sp, and m for each value of efficiency.
arrangement
arrangement.
model
model.
efficiency
a vector of efficiencies, one for each row of param.grid.

Details

One of m, p, sigma, se, or sp can have more than one value. m should not be greater than n[1]. For a ‘nested’ arrangement, m should be divisible by n[s] or n[s] should be divisible by m for all s. See Lendle et. al. 2011 for more information.

References

Samuel D. Lendle, Michael Hudgens, and Bahjat F. Qaqish, "Group Testing for Case Identification with Correlated Responses" Submitted 2011. Biometrics.

See Also

gtcorr.hierarchical.user

Examples

Run this code
##Plot efficiencies of a Dorfman (2 stage hierarchical) algorithm 
##by cluster size and sigma
m <- 2^(0:8)
sig.0 <- gtcorr.hierarchical(n=256, p=.001, m=m, sigma=0)$efficiency
sig.05 <- gtcorr.hierarchical(n=256, p=.001, m=m, sigma=0.05)$efficiency
sig.5 <- gtcorr.hierarchical(n=256, p=.001, m=m, sigma=0.5)$efficiency
sig.99 <- gtcorr.hierarchical(n=256, p=.001, m=m, sigma=.99)$efficiency

plot(m, sig.99, log="x", type='b', ylab="Efficiency", axes=FALSE)
box()
axis(1, at=m)
axis(2)
lines(m, sig.5, type='b', pch=22)
lines(m, sig.05, type='b', pch=23)
lines(m, sig.0, type='b', pch=24)
legend('bottomleft', c("sigma=0", "sigma=0.05", "sigma=0.5",
"sigma=0.99"), pch=21:24)

Run the code above in your browser using DataLab