Learn R Programming

gtcorr (version 0.2-1)

gtcorr.hierarchical.user: Calculate the efficiency of hierarchical group testing procedures for user specified arrangements

Description

‘gtcorr.hierarchical.user’ calculates the efficiencies of hierarchical group testing procedures, allowing for correlation between units and test error. Cluster arrangements can are specified by the user and probability of testing postive and correlation can vary by cluster.

Usage

gtcorr.hierarchical.user(n, clusters, p, sigma=0, se=1, sp=1, model = c("beta-binomial", "Morel-Neerchal", "Madsen"))

Arguments

n
a numeric vector of pool sizes where n[s] is the size of a pool in stage s. The size of a pool in the last stage is 1, which can be omitted.
clusters
a vector of length n[1] of integers from 1 up to the total number of clusters. cluster[i] is the ith unit's cluster.
p
probability of a unit testing positive. If the length is one, then all clusters have the same probability of testing positive. If the length is the total number of clusters, then p[k] is the probability that a unit in the kth cluster tests positive.
sigma
pairwise correlation of two units in a cluster. If the length is one, then all clusters have the same pairwise correlation. If the length is the total number of clusters, then sigma[k] is the pairwise correlation for the kth cluster.
se
sensitivity. The probability that a pool of units tests positive given than at least one unit in that pool is positive
sp
specificity. The probability that a pool of units tests negative given that at least one unit in that pool is negative
model
probability model for clusters. Should be ‘beta-binomial’, ‘Madsen’, or ‘Morel-Neerchal’.

Value

A length one vector containing the efficiency is returned

Details

Units are ordered such that the first pool in stage s contains units 1, ..., n[s], and the second pool in stage s has units (n[s]+1),...,(2*n[s]) and so forth.

References

Samuel D. Lendle, Michael Hudgens, and Bahjat F. Qaqish, "Group Testing for Case Identification with Correlated Responses" Submitted 2011. Biometrics.

See Also

gtcorr.hierarchical

Examples

Run this code
##Calculate the efficiency of a two stage hierarchical procedure with
##n[1]=20, where the first cluster has 10 units and the second and third
##clusters have 5 units each.
n <- 20
clusters <- c(rep(1,10), rep(2, 5), rep(3, 5))
p <- .1
sigma <- .3
gtcorr.hierarchical.user(n, clusters, p, sigma)

Run the code above in your browser using DataLab